/*
 * net.h
 *
 * This file is part of the msmtp package, a very simple programm that 
 * works as an "SMTP plugin" for Mutt and possibly other MUAs.
 *
 * Copyright (C) 2000, 2003, 2004
 * Martin Lambers <marlam@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *   msmtp is released under the GPL with the additional exemption that
 *   compiling, linking, and/or using OpenSSL is allowed.
 */

#ifndef NET_H
#define NET_H

#include "merror.h"

#define NET_ELIBFAILED		1	/* The underlying library failed */
#define NET_EHOSTNOTFOUND	2	/* Host not found */
#define NET_ESOCKET		3	/* Cannot create socket */
#define NET_ECONNECT		4	/* Cannot connect */
#define NET_EIO			5	/* Input/output error */

/*
 * net_init()
 *
 * Initializes the networking libraries.
 * Used error codes: NET_ELIBFAILED
 */
merror_t net_init(void);

/*
 * net_open_socket() 
 *
 * Opens a TCP socket to 'hostname':'port'.
 * 'hostname' may be a host name or an IPv4 address in dot notation.
 * If HAVE_GETADDRINFO is defined, it may also be an an IPv6 address in colon
 * notation. The file descriptor is returned in fd. 
 * Used error codes: NET_EHOSTNOTFOUND, NET_ESOCKET, NET_ECONNECT
 */
merror_t net_open_socket(char *hostname, int port, int *fd);

/*
 * net_getchar()
 *
 * Reads a character from 'fd' and stores it in 'c'.
 * Sets the 'eof' flag to 1 if EOF occurs and to 0 otherwise.
 * Used error codes: NET_EIO
 */
merror_t net_getchar(int fd, char *c, int *eof);

/*
 * net_getline()
 * 
 * Reads a line from 'fd' into 'line', which is of size 'size'.
 * The line end (either '\n' or '\r\n') is not stored in 'line'. 
 * 'line' will always be terminated by '\0'.
 * If the line is longer than 'size - 1' characters, 'is_longer' is set to 1,
 * otherwise 'is_longer' is set to 0.
 * The rest of the line can be read with subsequent calls.
 * Used error codes: NET_EIO
 */
merror_t net_getline(int fd, char *line, int size, int *is_longer);

/*
 * net_put()
 *
 * Writes a string to a file descriptor.
 * Used error codes: NET_EIO
 */
merror_t net_put(int fd, char *s);

/*
 * net_close_socket()
 *
 * Closes a socket.
 */
void net_close_socket(int fd);

/*
 * net_deinit()
 *
 * Deinit networking library
 */
void net_deinit(void);

#endif
